		/* The object of this library */
_timer
	var
		_start = 0
		_last = 0
		_running = 0
		_track = 0
		_ticks = 0
		_endtime = 0
		_paused = 0
		_pausestart = 0
		_pausetime = 0
		list/_records = null
					/* Set track to 1 if you'd like for this timer to act like a lap timer. */
					/* Set ticks to 1 if you'd like all times in ticks. */
					/* Set autostart to 1 if you'd like to automatically start the clock. */
	New(track, ticks, start = 0)
		. = ..()
		if(isnum(track) && track) _track = track
		if(isnum(ticks) && ticks) _ticks = ticks
		if(start) spawn Start()
	proc

					/* Start the timer if it is not running.. */
		Start()
			if(IsRunning()) return 0
			_start = world.time
			_running = 1
			_endtime = 0
			_last = 0
			return 1

					/* Stop the timer if is running. If it is acting as a lap timer, it adds it to the list. */
		Stop()
			if(!IsRunning()) return 0
			if(_paused) Pause()
			_last = world.time - _start - _pausetime
			_endtime = _last + _start
			Reset()
			spawn Done()
			if(_track)
				if(!_records) _records = new
				_records += _last
			return _last

					/* Restart the timer. This simply stops it, then starts it again, making it feasable */
		Restart()
			Stop()
			Start()

		Pause()
			_paused =! _paused
					/* Pause the timer */
			if(_paused)
				_pausestart = world.time
			else
					/* Unause the timer */
				_pausetime += world.time - _pausestart
				_pausestart = 0
			return _paused

		Done()

					/* Reset the timer. This simply resets the time the timer started, and stops running. */
		Reset()
			if(_start) _start = 0
			if(_running) _running = 0
			if(_paused) _paused = 0
			if(_pausetime) _pausetime = 0
			if(_pausestart) _pausestart = 0

					/* Returns true or false, depending on whether the timer is running or not. */
		IsRunning()
			return _running

					/* Returns whether or not times are in ticks. */
		InTicks()
			return _ticks

					/* Returns the time that the timer was started, in relation to the world startup time. */
		StartTime()
			if(_ticks)
				return _start
			else
				return _start / 10

					/* Returns the time that the timer was stopped, in relation to the clock startup time. */
		StopTime()
			if(_ticks)
				return _endtime
			else
				return _endtime / 10

					/* Returns the amount of time that the timer has been running so far.
						If track was set to true, it adds each run up. */
		Seconds()
			if(!_track || !_records)
				if(!IsRunning())
					if(_ticks)
						return _last - _pausetime
					else
						return _last - _pausetime / 10
				else
					if(_ticks)
						return world.time - _start - _pausetime + (world.time - _pausestart)
					else
						return (world.time - _start - _pausetime + (world.time - _pausestart)) / 10
			var/ctime = 0
			for(var/i in _records)
				ctime += i
			if(IsRunning()) ctime += world.time - _start - _pausetime + (world.time - _pausestart)
			if(_last) ctime += _last
			if(!_ticks) ctime /= 10
			return ctime

						/*****		LAP TIMER SPECIFIC STUFF		*****/
					/* Returns the time that trial n took, or -1 if it does not exist. */
		Trial(n)
			if(!isnum(n) || n < 0 || !_track || !_records ) return -1
			if(_ticks)
				return _records[n]
			else
				return _records[n] / 10

					/* Removes trial n from the records if it exists. Returns 1 on success. */
		RemoveTrial(n)
			if(!isnum(n) || n < 0 || !_track || !_records || !(n in _records)) return 0
			_records -= n
			if(!_records.len) _records = null
			return 1

					/* Returns the total number of trials ran, if any. */
		TrialCount()
			if(!_track || !_records) return 0
			return _records.len
